==> soledad-multiconcept-blogmagazine-wp-theme-8.6.6%28www.persianscript.ir%29.zip: penci-ai/admin/includes/ajax-requests/get-intro-and-conc.php <==
<?php

namespace PenciAIContentGenerator\AjaxRequests;

class GetIntroAndConc {

	private $ajax;

	/**
	 * PreloadCaches constructor.
	 */
	public function __construct( $a ) {
		$this->ajax = $a;
		add_action( "wp_ajax_get_intro_and_conc", [ $this, 'ajax' ] );
	}

	public function ajax() {
		\penciai_checkNonce();
		$ai = new \OpenAIAPI( get_theme_mod( 'penci_ai_api_key' ) );
		$default_model = get_theme_mod( 'penci_ai_model', 'gpt-3.5-turbo-instruct' );
		$ai->setModel( $default_model );

		$lang      = isset( $_POST['lang'] ) ? sanitize_text_field( $_POST['lang'] ) : "en";
		$lang_name = isset( $_POST['lang_name'] ) ? sanitize_text_field( $_POST['lang_name'] ) : "English";

		if ( ! empty( get_theme_mod( 'lang_' . $lang ) ) ) {
			wp_send_json_success( esc_html( get_theme_mod( 'lang_' . $lang ) ) );
			wp_die();
		}
		$data = [];

		$prompt = 'in the ' . $lang . ' language, what word is most used for "Introduction" and "Conclusion", output in js array.';

		if ( $default_model == 'gpt-3.5-turbo-instruct' ) {
			$data['prompt'] = $prompt;
		} else {
			$data['model'] = $default_model;
			$data['messages'] = array(
				array(
					'role'    => 'user',
					'content' => $prompt,
				),
			);
		}

		$response = $ai->complete( $data );
		if ( penciai_is_json( $response ) ) {
			$json = json_decode( $response );
			if ( isset( $json->choices ) ) {
				if ( $default_model == 'gpt-3.5-turbo-instruct' ) {
					$text    = $json->choices[0]->text;
				} else {
					$text = $json->choices[0]->message->content;
				}
				$text    = str_replace( "\n", '<br>', $text );
				$content = $text;
				//$ai->setResponse(esc_html($content));
				wp_send_json_success( esc_html( $content ) );
			} else {
				$obj      = json_decode( $response );
				$hasError = $this->ajax->is_response_has_error( $obj );
				if ( $hasError !== false ) {
					wp_send_json_error( $hasError );
				} else {
					wp_send_json_error( "__something_went_wrong__" );
				}
			}

		} else {
			wp_send_json_error( '__something_went_wrong__' );
		}
		var_dump( $response );
		wp_die();

	}
}

==> soledad-multiconcept-blogmagazine-wp-theme-8.6.9%28www.persianscript.ir%29.zip: penci-ai/admin/includes/ajax-requests/get-intro-and-conc.php <==
<?php

namespace PenciAIContentGenerator\AjaxRequests;

class GetIntroAndConc {

	private $ajax;

	/**
	 * PreloadCaches constructor.
	 */
	public function __construct( $a ) {
		$this->ajax = $a;
		add_action( "wp_ajax_get_intro_and_conc", [ $this, 'ajax' ] );
	}

	public function ajax() {
		\penciai_checkNonce();
		$ai = new \OpenAIAPI( get_theme_mod( 'penci_ai_api_key' ) );
		$default_model = get_theme_mod( 'penci_ai_model', 'gpt-3.5-turbo-instruct' );
		$ai->setModel( $default_model );

		$lang      = isset( $_POST['lang'] ) ? sanitize_text_field( $_POST['lang'] ) : "en";
		$lang_name = isset( $_POST['lang_name'] ) ? sanitize_text_field( $_POST['lang_name'] ) : "English";

		if ( ! empty( get_theme_mod( 'lang_' . $lang ) ) ) {
			wp_send_json_success( esc_html( get_theme_mod( 'lang_' . $lang ) ) );
			wp_die();
		}
		$data = [];

		$prompt = 'in the ' . $lang . ' language, what word is most used for "Introduction" and "Conclusion", output in js array.';

		if ( $default_model == 'gpt-3.5-turbo-instruct' ) {
			$data['prompt'] = $prompt;
		} else {
			$data['model'] = $default_model;
			$data['messages'] = array(
				array(
					'role'    => 'user',
					'content' => $prompt,
				),
			);
		}

		if ( in_array( $default_model, [ 'gpt-5', 'gpt-5-pro', 'gpt-5-thinking' ], true ) ) {
			// Example: adjust verbosity or reasoning_effort if desired
			$data['verbosity'] = 'medium'; // options: low, medium, high
			$data['reasoning_effort'] = $default_model === 'gpt-5-thinking' ? 'high' : 'medium';
		}

		$response = $ai->complete( $data );
		if ( penciai_is_json( $response ) ) {
			$json = json_decode( $response );
			if ( isset( $json->choices ) ) {
				if ( $default_model == 'gpt-3.5-turbo-instruct' ) {
					$text    = $json->choices[0]->text;
				} else {
					$text = $json->choices[0]->message->content;
				}
				$text    = str_replace( "\n", '<br>', $text );
				$content = $text;
				//$ai->setResponse(esc_html($content));
				wp_send_json_success( esc_html( $content ) );
			} else {
				$obj      = json_decode( $response );
				$hasError = $this->ajax->is_response_has_error( $obj );
				if ( $hasError !== false ) {
					wp_send_json_error( $hasError );
				} else {
					wp_send_json_error( "__something_went_wrong__" );
				}
			}

		} else {
			wp_send_json_error( '__something_went_wrong__' );
		}
		var_dump( $response );
		wp_die();

	}
}
